@@ -101,6 +101,10 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 0)
+#define f_vfsmnt f_path.mnt
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 38)
 
 /**
